# Neon Skill Utilities
![Unit Tests](https://github.com/NeonGeckoCom/neon-skill-utils/workflows/Run%20Unit%20Tests/badge.svg)

Collection of generic utilities used within Neon Core and Skills.
Contains utilities for running Neon Skills on Mycroft and OVOS.